@@ -34,7 +34,7 @@ struct _SpVisualizerTicks
   gint64 epoch;
   gint64 begin_time;
   gint64 end_time;
-} __attribute__((aligned(8)));
+};
 
 enum {
   TICK_MINUTES,
@@ -233,7 +233,7 @@ static gboolean
 sp_visualizer_ticks_draw (GtkWidget *widget,
                           cairo_t   *cr)
 {
-  SpVisualizerTicks *self = (SpVisualizerTicks *)widget;
+  SpVisualizerTicks *self = SP_VISUALIZER_TICKS (widget);
   GtkStyleContext *style;
   GtkAllocation alloc;
   GtkStateFlags state;
